@@ -66,12 +66,6 @@ class DjangoDataCollectorBase:
             self._sink.put(self.django_data)
         except Exception as e:
             logging.error("sink put error", exc_info=e)
-        finally:
-            self.close()
-
-    def close(self):
-        self.request = None
-        self.response = None
 
     def _collect_request_data(self):
         self._django_data["context"]["request_time"] = self._request_time.isoformat()
@@ -92,6 +86,10 @@ class DjangoDataCollectorBase:
             v = getattr(user, k, None)
             self._django_data["user"][name] = v
 
+        if "headers" in self._django_data["request"]:
+            headers: Dict[str, str] = self._get_request_headers()
+            self._django_data["request"]["headers"] = headers
+
         self._django_data["request"]["body"] = self.parsed_request_body()
 
     def _collect_response_data(self):
@@ -105,9 +103,10 @@ class DjangoDataCollectorBase:
             v = getattr(self.response, k, None)
             self._django_data["response"][name] = v
 
-        headers: Dict[str, str] = self._get_response_headers()
         if "headers" in self._django_data["response"]:
+            headers: Dict[str, str] = self._get_response_headers()
             self._django_data["response"]["headers"] = headers
+
         self._django_data["response"]["body"] = self.parsed_response_body()
 
     def _get_response_headers(self) -> Dict[str, str]:
@@ -122,6 +121,14 @@ class DjangoDataCollectorBase:
             return {self._normalize_header_key(k): v for k, v in _header_values}
         return {}
 
+    def _get_request_headers(self) -> Dict[str, str]:
+        if hasattr(self.request, "headers"):
+            return {
+                self._normalize_header_key(k): v
+                for k, v in self.request.headers.items()
+            }
+        return {}
+
     def request_raw_data(self) -> bytes:
         return self.request.body
 
