@@ -1,6 +1,5 @@
 import asyncio
 import uuid
-from concurrent.futures import ThreadPoolExecutor
 from typing import Optional
 
 from django.http import HttpResponse, HttpRequest
@@ -39,7 +38,6 @@ class DjangoDataTopMiddleware(_MiddlewareBase):
     def __init__(self, get_response):
         super(DjangoDataTopMiddleware, self).__init__(get_response)
         self.data_collector: Optional[DjangoDataCollectorBase] = None
-        self.put_threadpool = ThreadPoolExecutor()
 
     def __call__(self, request: HttpRequest):
         # attach a request_id for to this request
@@ -55,7 +53,6 @@ class DjangoDataTopMiddleware(_MiddlewareBase):
 
         self.data_collector.attach_response(response)
         self.data_collector.do_collect()
-        self.put_threadpool.submit(self.data_collector.do_collect)
         return response
 
     async def __acall__(self, request):
@@ -63,7 +60,11 @@ class DjangoDataTopMiddleware(_MiddlewareBase):
         self.data_collector.attach_request(request)
         response = await self.get_response(request)
         self.data_collector.attach_response(response)
-        self.put_threadpool.submit(self.data_collector.do_collect)
+        # DB related operation is async-unsafe
+        f = asyncio.get_running_loop().run_in_executor(
+            None, self.data_collector.do_collect
+        )
+        await f
         return response
 
 
